import { existsSync, realpathSync } from 'fs';
import { readFile } from 'fs/promises';
import micromatch from 'micromatch';
import path, { resolve } from 'path';

function createPatternMatcher(patterns) {
  if (!patterns || Array.isArray(patterns) && patterns.length === 0 || patterns === "") {
    return () => true;
  }
  return (fileName) => isMatch(fileName, patterns);
}
function isMatch(fileName, pattern, options) {
  const absoluteFilePath = path.resolve(fileName);
  const normalizedFilePath = path.relative(process.cwd(), absoluteFilePath).replace(/\\/g, "/");
  const baseOptions = { dot: true, bash: true, basename: true, ...options };
  if (Array.isArray(pattern)) {
    const positivePatterns = pattern.filter((p) => !p.startsWith("!"));
    const negativePatterns = pattern.filter((p) => p.startsWith("!")).map((p) => p.slice(1));
    const positiveMatch = positivePatterns.length === 0 || micromatch.isMatch(normalizedFilePath, positivePatterns, baseOptions);
    const negativeMatch = negativePatterns.length > 0 && micromatch.isMatch(normalizedFilePath, negativePatterns, baseOptions);
    return positiveMatch && !negativeMatch;
  }
  return micromatch.isMatch(normalizedFilePath, pattern, baseOptions);
}
async function waitForFile(filePath, timeout = 5e3) {
  const start = Date.now();
  while (Date.now() - start < timeout)
    if (existsSync(filePath)) {
      try {
        await readFile(filePath, "utf-8");
        return;
      } catch {
        await new Promise((resolve2) => setTimeout(resolve2, 100));
      }
    }
  throw new Error(`File not available after ${timeout}ms: ${filePath}`);
}
function normalizePath(p, shouldResolve = false) {
  const resolved = shouldResolve && existsSync(p) ? realpathSync(path.resolve(p)) : p;
  return resolved.replace(/\\/g, "/");
}
function normalizeAndResolvePath(p) {
  return normalizePath(resolve(p), true);
}
const np = normalizePath;
function isPathEqual(path1, path2) {
  return resolve(normalizePath(path1)) === resolve(normalizePath(path2));
}

export { createPatternMatcher, isMatch, isPathEqual, normalizeAndResolvePath, normalizePath, np, waitForFile };
//# sourceMappingURL=utils.js.map
//# sourceMappingURL=utils.js.map